@@ -10,9 +10,9 @@ has odd_fgcolor  => (is => 'rw');
 has even_fgcolor => (is => 'rw');
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-02-14'; # DATE
+our $DATE = '2023-07-14'; # DATE
 our $DIST = 'Text-ANSITable'; # DIST
-our $VERSION = '0.608'; # VERSION
+our $VERSION = '0.609'; # VERSION
 
 sub summary {
     "Set different foreground and/or background color for odd/even rows";
@@ -58,7 +58,7 @@ Text::ANSITable::StyleSet::AltRow - Set different foreground and/or background c
 
 =head1 VERSION
 
-This document describes version 0.608 of Text::ANSITable::StyleSet::AltRow (from Perl distribution Text-ANSITable), released on 2022-02-14.
+This document describes version 0.609 of Text::ANSITable::StyleSet::AltRow (from Perl distribution Text-ANSITable), released on 2023-07-14.
 
 =for Pod::Coverage ^(summary|apply)$
 
@@ -97,13 +97,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2021, 2020, 2018, 2017, 2016, 2015, 2014, 2013 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2021, 2020, 2018, 2017, 2016, 2015, 2014, 2013 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
